@@ -11,7 +11,7 @@ use URI::Escape;
 use JSON::XS qw/decode_json/;
 use Encode;
 
-our $VERSION = 0.09;
+our $VERSION = 0.11;
 
 sub new {
   my ($class, %args) = @_;
@@ -33,8 +33,8 @@ sub new {
 sub search {
   my ($self, $query) = @_;
 
-  my $res = $self->{ua}->get('http://vk.com/search?c[section]=audio&c[q]='.uri_escape_utf8($query));
-  die 'LWP: '.$res->status_line unless $res->is_success;
+  my $res = $self->{ua}->get('https://vk.com/search?c[section]=audio&c[q]='.uri_escape_utf8($query));
+  die 'lwp: '.$res->status_line unless $res->is_success;
 
   my @matches = $res->decoded_content =~  m'<input type="hidden" id="audio_info(.*?)</tbody></table>'sgi;
 
@@ -49,7 +49,7 @@ sub get_playlist {
   my ($self) = @_;
   my $res;
 
-  $res = $self->{ua}->post('http://vk.com/audio', {
+  $res = $self->{ua}->post('https://vk.com/audio', {
         act => 'load_audios_silent',
         al => 1,
         gid => 0,
@@ -90,7 +90,7 @@ sub _parse_found_item {
   $name = decode_entities($name);
 
   my ($duration) = $str =~ m{<div class="duration fl_r".*?>(\d+:\d+)</div>}i;
-  my ($link) = $str =~ m{value="(http://[^",]+\.mp3)}i;
+  my ($link) = $str =~ m{value="(https?://[^",]+\.mp3)}i;
 
   if($duration) {
     my ($min, $sec) = split /:/, $duration, 2;
@@ -104,22 +104,40 @@ sub _parse_found_item {
 
 sub _login {
   my $self = shift;
-  my $res = $self->{ua}->post('https://login.vk.com/?act=login', {
+
+  my $res = $self->{ua}->get('https://vk.com/');
+  die 'lwp: '.$res->status_line unless $res->is_success;
+
+  my ($ip_h) = $res->decoded_content =~  m'<input type="hidden" name="ip_h" value="([^"]+)" />'sgi;
+  my ($lg_h) = $res->decoded_content =~  m'<input type="hidden" name="lg_h" value="([^"]+)" />'sgi;
+
+  return 1 unless $ip_h && $lg_h;
+
+  $res = $self->{ua}->post('https://login.vk.com/?act=login', {
       email => $self->{login},
       pass => $self->{password},
+      act => "login",
+      role => "al_frame",
+      expire => "",
+      captcha_sid => "",
+      captcha_key => "",
+      _origin => "https://vk.com",
+      ip_h => $ip_h,
+      lg_h => $lg_h,
     });  
 
   if(  $res->is_success &&
-      ($res->decoded_content =~ /var\s+vk\s*=\s*\{[^\{\}]*?id\s*\:\s*(\d+)/i
-       || $res->decoded_content =~ m#login\.vk\.com/\?act=logout#i ) ) {
+      ($res->decoded_content =~ /parent\.onLoginDone/i) &&
+      ($res->decoded_content =~ /"uid":"(\d+)"/i)) {
     $self->{id} = $1;
     return 1;
   }
+
   return 0;
 }
 
 sub _create_ua {
-  my $ua = LWP::UserAgent->new();
+  my $ua = LWP::UserAgent->new(agent => "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/47.0.2526.106 Chrome/47.0.2526.106 Safari/537.36");
 
   push @{ $ua->requests_redirectable }, 'POST';
   $ua->cookie_jar( {} );
@@ -216,11 +234,11 @@ L<VK>, L<VKontakte::API>, L<LWP::UserAgent>.
 
 =head1 AUTHOR
 
-Alexandr Alexeev, <eax at cpan.org> (L<http://eax.me/>)
+Aleksander Alekseev, <eax at cpan.org> (L<http://eax.me/>)
 
 =head1 COPYRIGHT
 
-Copyright 2011-2012 by Alexandr Alexeev
+Copyright 2011-2016 by Aleksander Alekseev
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
